@@ -8,7 +8,7 @@ import time
 import skrt.core
 from skrt.image import Image
 from skrt.structures import StructureSet
-from skrt.dose import Dose
+from skrt.dose import Dose, Plan
 
 
 class Study(skrt.core.Archive):
@@ -41,6 +41,14 @@ class Study(skrt.core.Archive):
             load=False
         )
 
+        # Load treament plans
+        self.load_from_subdir(
+            dtype=Plan,
+            subdir="RTPLAN",
+            attr_name="plans",
+            load=False
+        )
+
         #  self.load_dose_or_plan()
 
     def load_images(self):
@@ -97,7 +105,8 @@ class Study(skrt.core.Archive):
         for im_type_dir in os.listdir(obj_dir):
 
             im_type = im_type_dir
-            if subdir in ['RTDOSE'] and im_type not in self.image_types:
+            if subdir in ['RTDOSE', 'RTPLAN'] \
+                    and im_type not in self.image_types:
                 im_type = 'CT'
             subpath = f"{subdir}/{im_type_dir}"
 
